# conventional-tidelift-releaser

> Publish release notes to Tidelift from Git metadata.

**Note:** Release notes are generated by assuming your project follows the [Conventional Commits convention](https://conventionalcommits.org). If that's not the case, please consider using a more appropriate convention preset package with the `preset` option.

## Table of Contents
<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->


- [Docker](#docker)
- [Debugging](#debugging)
- [Node Support Policy](#node-support-policy)
- [Contributing](#contributing)
- [License](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

## Docker

> **Note:** This example uses an unofficial Docker image built against the latest source code contained in this repository.

> **Note:** This _should_ work regardless of programming language as it interacts directly with Git. If you find that's not the case, please file an issue with our repository so that we may investigate.

First, navigate into the top level directory of the project for which you want to publish release notes to Tidelift.

Then run the following:

```bash
docker run --volume "$(pwd)":/app hutson/conventional-tidelift-releaser:latest --token "${TIDELIFT_TOKEN} --platform "npm" --package "conventional-tidelift-releaser" --release-count 0
```

In the example above we are publishing all release notes for the `conventional-tidelift-releaser` npm package using our Tidelift token stored in the `TIDELIFT_TOKEN` environment variable.

For `conventional-tidelift-releaser` to generate release notes it needs access to the Git metadata, which is why we mount the project's directory to the `/app` folder within the Docker container using `--volume "$(pwd)":/app`.

Lastly, all arguments passed to Docker after the image name, `conventional-tidelift-releaser:latest`, are passed to `conventional-tidelift-releaser`. You can find a full list of available options by calling `docker run hutson/conventional-tidelift-releaser:latest --help`.

If you would like to print debug logs add `--env DEBUG=conventional-tidelift-releaser` right after `docker run`:

```bash
docker run --env DEBUG=conventional-tidelift-releaser ...
```

## Debugging

To assist users of `conventional-tidelift-releaser` with debugging the behavior of this module we use the [debug](https://www.npmjs.com/package/debug) utility package to print information about the release process to the console. To enable debug message printing, the environment variable `DEBUG`, which is the variable used by the `debug` package, must be set to a value configured by the package containing the debug messages to be printed.

To print debug messages on a unix system set the environment variable `DEBUG` with the name of this package prior to executing `conventional-tidelift-releaser`:

```bash
DEBUG=conventional-tidelift-releaser conventional-tidelift-releaser
```

On the Windows command line you may do:

```bash
set DEBUG=conventional-tidelift-releaser
conventional-tidelift-releaser
```

## Node Support Policy

We only support [Long-Term Support](https://github.com/nodejs/Release) versions of Node.

We specifically limit our support to LTS versions of Node, not because this package won't work on other versions, but because we have a limited amount of time, and supporting LTS offers the greatest return on that investment.

It's possible this package will work correctly on newer versions of Node. It may even be possible to use this package on older versions of Node, though that's more unlikely as we'll make every effort to take advantage of features available in the oldest LTS version we support.

As each Node LTS version reaches its end-of-life we will remove that version from the `node` `engines` property of our package's `package.json` file. Removing a Node version is considered a breaking change and will entail the publishing of a new major version of this package. We will not accept any requests to support an end-of-life version of Node. Any merge requests or issues supporting an end-of-life version of Node will be closed.

We will accept code that allows this package to run on newer, non-LTS, versions of Node. Furthermore, we will attempt to ensure our own changes work on the latest version of Node. To help in that commitment, our continuous integration setup runs against all LTS versions of Node in addition the most recent Node release; called _current_.

JavaScript package managers should allow you to install this package with any version of Node, with, at most, a warning if your version of Node does not fall within the range specified by our `node` `engines` property. If you encounter issues installing this package, please report the issue to your package manager.

## Contributing

Please read our [contributing guide](https://github.com/conventional-changelog/releaser-tools/blob/master/CONTRIBUTING.md) to see how you may contribute to this project.

## License

MIT © [Steve Mao](https://github.com/stevemao)
